[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit ea80d59f9fdd19bbb128caf7b136fcd3eac87c35
Author: Juergen E. Fischer j...@norbit.de
Date:   Wed Feb 29 21:22:15 2012 +0100

fix warnings

diff --git a/src/app/qgisapp.cpp b/src/app/qgisapp.cpp
index 6eff2d5..6cec2d6 100644
--- a/src/app/qgisapp.cpp
+++ b/src/app/qgisapp.cpp
@@ -628,7 +628,7 @@ QgisApp::QgisApp( QSplashScreen *splash, bool 
restorePlugins, QWidget * parent,
 
 #ifdef ANDROID
   //add reacting to long click in android
-  grabGesture(Qt::TapAndHoldGesture);
+  grabGesture( Qt::TapAndHoldGesture );
 #endif
 
   // update windows
@@ -741,9 +741,9 @@ bool QgisApp::event( QEvent * event )
 done = true;
   }
 #ifdef ANDROID
-  else if (event-type() == QEvent::Gesture )
+  else if ( event-type() == QEvent::Gesture )
   {
-done = gestureEvent(static_castQGestureEvent*(event));
+done = gestureEvent( static_castQGestureEvent*( event ) );
   }
 #endif
   else
@@ -7293,18 +7293,19 @@ QMenu* QgisApp::createPopupMenu()
 }
 
 #ifdef ANDROID
-bool QgisApp::gestureEvent(QGestureEvent *event)
+bool QgisApp::gestureEvent( QGestureEvent *event )
 {
-  if (QGesture *tapAndHold = event-gesture(Qt::TapAndHoldGesture))
+  if ( QGesture *tapAndHold = event-gesture( Qt::TapAndHoldGesture ) )
   {
-tapAndHoldTriggered(static_castQTapAndHoldGesture *(tapAndHold));
+tapAndHoldTriggered( static_castQTapAndHoldGesture *( tapAndHold ) );
   }
   return true;
 }
 
-void QgisApp::tapAndHoldTriggered(QTapAndHoldGesture *gesture)
+void QgisApp::tapAndHoldTriggered( QTapAndHoldGesture *gesture )
 {
-  if (gesture-state() == Qt::GestureFinished) {
+  if ( gesture-state() == Qt::GestureFinished )
+  {
 QPoint pos = gesture-position().toPoint();
 QWidget * receiver = QApplication::widgetAt( pos );
 qDebug()  tapAndHoldTriggered: LONG CLICK gesture happened at   pos;
diff --git a/src/app/qgisapp.h b/src/app/qgisapp.h
index 03dd077..c56828b 100644
--- a/src/app/qgisapp.h
+++ b/src/app/qgisapp.h
@@ -1165,8 +1165,8 @@ class QgisApp : public QMainWindow, private Ui::MainWindow
 QString mOldScale;
 
 #ifdef ANDROID
-bool gestureEvent(QGestureEvent *event);
-void tapAndHoldTriggered(QTapAndHoldGesture *gesture);
+bool gestureEvent( QGestureEvent *event );
+void tapAndHoldTriggered( QTapAndHoldGesture *gesture );
 #endif
 };
 
diff --git a/src/app/qgsmaptooloffsetcurve.cpp 
b/src/app/qgsmaptooloffsetcurve.cpp
index f125b78..689f132 100644
--- a/src/app/qgsmaptooloffsetcurve.cpp
+++ b/src/app/qgsmaptooloffsetcurve.cpp
@@ -484,5 +484,6 @@ QgsGeometry* QgsMapToolOffsetCurve::convertToSingleLine( 
QgsGeometry* geom, int
 
 QgsGeometry* QgsMapToolOffsetCurve::convertToMultiLine( QgsGeometry* geom )
 {
+  Q_UNUSED( geom );
   return 0;
 }
diff --git a/src/core/qgsgeometry.cpp b/src/core/qgsgeometry.cpp
index b3890d3..a83b5dc 100644
--- a/src/core/qgsgeometry.cpp
+++ b/src/core/qgsgeometry.cpp
@@ -6156,8 +6156,6 @@ QgsGeometry* QgsGeometry::combine( QgsGeometry* geometry )
   try
   {
 GEOSGeometry* unionGeom = GEOSUnion( mGeos, geometry-mGeos );
-QGis::WkbType thisGeomType = wkbType();
-QGis::WkbType otherGeomType = geometry-wkbType();
 if ( type() == QGis::Line )
 {
   GEOSGeometry* mergedGeom = GEOSLineMerge( unionGeom );
diff --git a/src/core/qgslabel.cpp b/src/core/qgslabel.cpp
index 4f02498..054f688 100644
--- a/src/core/qgslabel.cpp
+++ b/src/core/qgslabel.cpp
@@ -593,6 +593,8 @@ unsigned char* QgsLabel::labelPoint( labelpoint point, 
unsigned char *geom, siz
   QGis::WkbType wkbType;
 #ifndef QT_NO_DEBUG
   unsigned char *geomend = geom + geomlen;
+#else
+  Q_UNUSED( geomlen );
 #endif
   Q_ASSERT( geom + 1 + sizeof( wkbType ) = geomend );
 
diff --git a/src/providers/wms/qgswmsprovider.cpp 
b/src/providers/wms/qgswmsprovider.cpp
index b3687ea..d50ff57 100644
--- a/src/providers/wms/qgswmsprovider.cpp
+++ b/src/providers/wms/qgswmsprovider.cpp
@@ -2959,7 +2959,7 @@ QStringList QgsWmsProvider::identifyAs( const QgsPoint 
point, QString format )
 setQueryItem( requestUrl, X, QString::number( point.x() ) );
 setQueryItem( requestUrl, Y, QString::number( point.y() ) );
 
-if( mFeatureCount  0 )
+if ( mFeatureCount  0 )
 {
   setQueryItem( requestUrl, FEATURE_COUNT, QString::number( 
mFeatureCount ) );
 }
diff --git a/src/providers/wms/qgswmssourceselect.cpp 
b/src/providers/wms/qgswmssourceselect.cpp
index d29a2a1..b5c06e3 100644
--- a/src/providers/wms/qgswmssourceselect.cpp
+++ b/src/providers/wms/qgswmssourceselect.cpp
@@ -473,7 +473,7 @@ void QgsWMSSourceSelect::addClicked()
 
   if ( mFeatureCount-text().toInt()  0 )
   {
-if( !connArgs.isEmpty() )
+if ( !connArgs.isEmpty() )
   connArgs += ,;
 connArgs += QString( featureCount=%1 ).arg( 
mFeatureCount-text().toInt() );
   }

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel

[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit dde9ed7373731bc4f3e953a8a44fde3611640e0b
Author: Juergen E. Fischer j...@norbit.de
Date:   Mon Mar 5 20:22:46 2012 +0100

debian packaging update

diff --git a/debian/changelog b/debian/changelog
index 1a4c468..d474299 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -6,8 +6,10 @@ qgis (1.9.90) UNRELEASED; urgency=low
   * drop extra include path for QtWebkit on oneiric and natty
   * add translations for desktop link
   * add browser desktop entry
+  * add support for Ubuntu precise
+  * build package with libspatialite where available
 
- -- Jürgen E. Fischer j...@norbit.de  Thu, 23 Feb 2012 09:36:48 +0100
+ -- Jürgen E. Fischer j...@norbit.de  Mon, 05 Mar 2012 20:21:48 +0100
 
 qgis (1.8.0) UNRELEASED; urgency=low
 
diff --git a/debian/compat.lucid b/debian/compat.precise
similarity index 100%
copy from debian/compat.lucid
copy to debian/compat.precise
diff --git a/debian/control.natty b/debian/control.precise
similarity index 100%
copy from debian/control.natty
copy to debian/control.precise
diff --git a/debian/rules b/debian/rules
index 74ce5ef..500f509 100755
--- a/debian/rules
+++ b/debian/rules
@@ -10,7 +10,7 @@ DEB_HOST_GNU_TYPE   ?= $(shell dpkg-architecture 
-qDEB_HOST_GNU_TYPE)
 DEB_BUILD_GNU_TYPE  ?= $(shell dpkg-architecture -qDEB_BUILD_GNU_TYPE)
 
 DISTRIBUTION := $(shell dpkg-parsechangelog --format rfc822 | sed -ne 
s/^Distribution: //p)
-ifneq ($(DISTRIBUTION),$(findstring $(DISTRIBUTION),squeeze hardy intrepid 
jaunty karmic lucid maverick natty oneiric))
+ifneq ($(DISTRIBUTION),$(findstring $(DISTRIBUTION),squeeze hardy intrepid 
jaunty karmic lucid maverick natty oneiric precise))
 DISTRIBUTION := sid
 endif
 
@@ -32,17 +32,17 @@ CMAKE_OPTS := \
-D QGIS_CGIBIN_SUBDIR=/usr/lib/cgi-bin \
-D WITH_APIDOC=TRUE
 
-#ifeq (,$(findstring $(DISTRIBUTION),squeeze lucid maverick natty oneiric 
sid))
+ifeq (,$(findstring $(DISTRIBUTION),squeeze lucid maverick natty oneiric 
precise sid))
CMAKE_OPTS += -D WITH_INTERNAL_SPATIALITE=TRUE
-#else
-#  CMAKE_OPTS += -D WITH_INTERNAL_SPATIALITE=FALSE
-#endif
+else
+   CMAKE_OPTS += -D WITH_INTERNAL_SPATIALITE=FALSE
+endif
 
 ifneq (,$(findstring $(DISTRIBUTION),sid))
CMAKE_OPTS += -D WITH_GLOBE=TRUE
 endif
 
-ifneq (,$(findstring $(DISTRIBUTION),squeeze lucid maverick natty oneiric 
sid))
+ifneq (,$(findstring $(DISTRIBUTION),squeeze lucid maverick natty oneiric 
precise sid))
CMAKE_OPTS += -D WITH_INTERNAL_SPATIALINDEX=FALSE
 endif
 

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel

[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit c58debc638f2c87933dd371710bd107d3c7a5092
Author: Juergen E. Fischer j...@norbit.de
Date:   Mon Mar 5 20:23:47 2012 +0100

postgresql provider: don't require access to geometry_columns

diff --git a/src/providers/postgres/qgspostgresconn.cpp 
b/src/providers/postgres/qgspostgresconn.cpp
index d47a339..47de53e 100644
--- a/src/providers/postgres/qgspostgresconn.cpp
+++ b/src/providers/postgres/qgspostgresconn.cpp
@@ -349,44 +349,38 @@ bool QgsPostgresConn::getTableInfo( bool 
searchGeometryColumnsOnly, bool searchP
 if ( result.PQresultStatus() != PGRES_TUPLES_OK )
 {
   PQexecNR( COMMIT );
-
-  if ( i == 0 )
-return false;
-
   continue;
 }
-else
+
+nGTables++;
+
+for ( int idx = 0; idx  result.PQntuples(); idx++ )
 {
-  nGTables++;
+  QString tableName = result.PQgetvalue( idx, 0 );
+  QString schemaName = result.PQgetvalue( idx, 1 );
+  QString column = result.PQgetvalue( idx, 2 );
+  QString type = result.PQgetvalue( idx, 3 );
+  QString srid = result.PQgetvalue( idx, 4 );
+  QString relkind = result.PQgetvalue( idx, 5 );
+
+  QgsDebugMsg( QString( %1 : %2.%3.%4: %5 %6 %7 )
+ .arg( gtableName )
+ .arg( schemaName ).arg( tableName ).arg( column )
+ .arg( type )
+ .arg( srid )
+ .arg( relkind ) );
+
+  layerProperty.type = type;
+  layerProperty.schemaName = schemaName;
+  layerProperty.tableName = tableName;
+  layerProperty.geometryColName = column;
+  layerProperty.pkCols = relkind == v ? pkCandidates( schemaName, 
tableName ) : QStringList();
+  layerProperty.srid = srid;
+  layerProperty.sql = ;
+  layerProperty.isGeography = i == 1;
 
-  for ( int idx = 0; idx  result.PQntuples(); idx++ )
-  {
-QString tableName = result.PQgetvalue( idx, 0 );
-QString schemaName = result.PQgetvalue( idx, 1 );
-QString column = result.PQgetvalue( idx, 2 );
-QString type = result.PQgetvalue( idx, 3 );
-QString srid = result.PQgetvalue( idx, 4 );
-QString relkind = result.PQgetvalue( idx, 5 );
-
-QgsDebugMsg( QString( %1 : %2.%3.%4: %5 %6 %7 )
- .arg( gtableName )
- .arg( schemaName ).arg( tableName ).arg( column )
- .arg( type )
- .arg( srid )
- .arg( relkind ) );
-
-layerProperty.type = type;
-layerProperty.schemaName = schemaName;
-layerProperty.tableName = tableName;
-layerProperty.geometryColName = column;
-layerProperty.pkCols = relkind == v ? pkCandidates( schemaName, 
tableName ) : QStringList();
-layerProperty.srid = srid;
-layerProperty.sql = ;
-layerProperty.isGeography = i == 1;
-
-mLayersSupported  layerProperty;
-nColumns++;
-  }
+  mLayersSupported  layerProperty;
+  nColumns++;
 }
   }
 
diff --git a/src/providers/postgres/qgspostgresprovider.cpp 
b/src/providers/postgres/qgspostgresprovider.cpp
index edfba5c..5060e29 100644
--- a/src/providers/postgres/qgspostgresprovider.cpp
+++ b/src/providers/postgres/qgspostgresprovider.cpp
@@ -2682,10 +2682,14 @@ bool QgsPostgresProvider::getGeometryDetails()
   detectedType = result.PQgetvalue( 0, 0 );
   detectedSrid = result.PQgetvalue( 0, 1 );
 }
+else
+{
+  mConnectionRO-PQexecNR( COMMIT );
+}
 
-if ( !detectedType.isEmpty() )
+if ( detectedType.isEmpty() )
 {
-  // check geometry columns
+  // check geography columns
   sql = QString( SELECT upper(type),srid FROM geography_columns WHERE 
f_table_name=%1 AND f_geography_column=%2 AND f_table_schema=%3 )
 .arg( quotedValue( tableName ) )
 .arg( quotedValue( geomCol ) )
@@ -2695,18 +2699,15 @@ bool QgsPostgresProvider::getGeometryDetails()
   result = mConnectionRO-PQexec( sql, false );
   QgsDebugMsg( QString( Geography column query returned %1 ).arg( 
result.PQntuples() ) );
 
-  if ( result.PQresultStatus() == PGRES_TUPLES_OK )
+  if ( result.PQntuples() == 1 )
   {
-if ( result.PQntuples() == 1 )
-{
-  detectedType = result.PQgetvalue( 0, 0 );
-  detectedSrid = result.PQgetvalue( 0, 1 );
-  mIsGeography = true;
-}
+detectedType = result.PQgetvalue( 0, 0 );
+detectedSrid = result.PQgetvalue( 0, 1 );
+mIsGeography = true;
   }
   else
   {
-mConnectionRO-PQexecNR( ROLLBACK );
+mConnectionRO-PQexecNR( COMMIT );
   }
 }
   }

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 9843384a765e56a11a3bd81e11ac9bd49cd2c95d
Author: Juergen E. Fischer j...@norbit.de
Date:   Tue Mar 6 13:52:31 2012 +0100

fix #2766

diff --git a/src/gui/qgsquerybuilder.cpp b/src/gui/qgsquerybuilder.cpp
index 3fa16ab..8094c4b 100644
--- a/src/gui/qgsquerybuilder.cpp
+++ b/src/gui/qgsquerybuilder.cpp
@@ -285,7 +285,7 @@ void QgsQueryBuilder::on_lstValues_doubleClicked( const 
QModelIndex index )
   else if ( value.type() == QVariant::Int || value.type() == QVariant::Double 
|| value.type() == QVariant::LongLong )
 txtSQL-insertPlainText( value.toString() );
   else
-txtSQL-insertPlainText( ' + value.toString() + ' );
+txtSQL-insertPlainText( ' + value.toString().replace( ', '' ) + ' 
);
 }
 
 void QgsQueryBuilder::on_btnLessEqual_clicked()

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 407832a9c72f6e6e1ef155c74ac6108d1ac61bd6
Author: Juergen E. Fischer j...@norbit.de
Date:   Tue Mar 6 13:53:26 2012 +0100

expression builder: only fetch geometry when required (and available)

diff --git a/src/gui/qgsexpressionbuilderwidget.cpp 
b/src/gui/qgsexpressionbuilderwidget.cpp
index 9164f81..450770a 100644
--- a/src/gui/qgsexpressionbuilderwidget.cpp
+++ b/src/gui/qgsexpressionbuilderwidget.cpp
@@ -249,7 +249,7 @@ void 
QgsExpressionBuilderWidget::on_txtExpressionString_textChanged()
   {
 if ( !mFeature.isValid() )
 {
-  mLayer-select( mLayer-pendingAllAttributesList() );
+  mLayer-select( mLayer-pendingAllAttributesList(), QgsRectangle(), 
mLayer-geometryType() != QGis::NoGeometry  exp.needsGeometry() );
   mLayer-nextFeature( mFeature );
 }
 

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 24a1fb90a75653a9232094bf63a6a8911670db50
Author: Juergen E. Fischer j...@norbit.de
Date:   Tue Mar 6 13:53:37 2012 +0100

fix warning

diff --git a/src/providers/postgres/qgspostgresconn.cpp 
b/src/providers/postgres/qgspostgresconn.cpp
index 47de53e..bb57984 100644
--- a/src/providers/postgres/qgspostgresconn.cpp
+++ b/src/providers/postgres/qgspostgresconn.cpp
@@ -364,11 +364,11 @@ bool QgsPostgresConn::getTableInfo( bool 
searchGeometryColumnsOnly, bool searchP
   QString relkind = result.PQgetvalue( idx, 5 );
 
   QgsDebugMsg( QString( %1 : %2.%3.%4: %5 %6 %7 )
- .arg( gtableName )
- .arg( schemaName ).arg( tableName ).arg( column )
- .arg( type )
- .arg( srid )
- .arg( relkind ) );
+   .arg( gtableName )
+   .arg( schemaName ).arg( tableName ).arg( column )
+   .arg( type )
+   .arg( srid )
+   .arg( relkind ) );
 
   layerProperty.type = type;
   layerProperty.schemaName = schemaName;
@@ -498,7 +498,7 @@ bool QgsPostgresConn::getTableInfo( bool 
searchGeometryColumnsOnly, bool searchP
   QgsMessageLog::logMessage( tr( Database connection was successful, but 
the accessible tables could not be determined.\nThe error message from the 
database was:\n%1 )
  .arg( result.PQresultErrorMessage() ),
  tr( PostGIS ) );
-  return -1;
+  return false;
 }
 
 for ( int i = 0; i  result.PQntuples(); i++ )

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 2e6bf626beb64a6ff4d344505507226bd7db13db
Author: Juergen E. Fischer j...@norbit.de
Date:   Tue Mar 6 20:38:31 2012 +0100

debian packaging update: add wheezy and use internal spatialite where 
libspatialite3 not available

diff --git a/debian/changelog b/debian/changelog
index d474299..a596437 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -6,10 +6,10 @@ qgis (1.9.90) UNRELEASED; urgency=low
   * drop extra include path for QtWebkit on oneiric and natty
   * add translations for desktop link
   * add browser desktop entry
-  * add support for Ubuntu precise
-  * build package with libspatialite where available
+  * add support for Debian wheezy and Ubuntu precise
+  * build package with internal libspatialite where libspatialite not available
 
- -- Jürgen E. Fischer j...@norbit.de  Mon, 05 Mar 2012 20:21:48 +0100
+ -- Jürgen E. Fischer j...@norbit.de  Tue, 06 Mar 2012 20:33:08 +0100
 
 qgis (1.8.0) UNRELEASED; urgency=low
 
diff --git a/debian/control.sid b/debian/control.wheezy
similarity index 100%
copy from debian/control.sid
copy to debian/control.wheezy
diff --git a/debian/rules b/debian/rules
index 500f509..5b461d4 100755
--- a/debian/rules
+++ b/debian/rules
@@ -10,7 +10,7 @@ DEB_HOST_GNU_TYPE   ?= $(shell dpkg-architecture 
-qDEB_HOST_GNU_TYPE)
 DEB_BUILD_GNU_TYPE  ?= $(shell dpkg-architecture -qDEB_BUILD_GNU_TYPE)
 
 DISTRIBUTION := $(shell dpkg-parsechangelog --format rfc822 | sed -ne 
s/^Distribution: //p)
-ifneq ($(DISTRIBUTION),$(findstring $(DISTRIBUTION),squeeze hardy intrepid 
jaunty karmic lucid maverick natty oneiric precise))
+ifneq ($(DISTRIBUTION),$(findstring $(DISTRIBUTION),squeeze wheezy hardy 
intrepid jaunty karmic lucid maverick natty oneiric precise))
 DISTRIBUTION := sid
 endif
 
@@ -32,10 +32,10 @@ CMAKE_OPTS := \
-D QGIS_CGIBIN_SUBDIR=/usr/lib/cgi-bin \
-D WITH_APIDOC=TRUE
 
-ifeq (,$(findstring $(DISTRIBUTION),squeeze lucid maverick natty oneiric 
precise sid))
-   CMAKE_OPTS += -D WITH_INTERNAL_SPATIALITE=TRUE
-else
+ifeq ($(DISTRIBUTION),$(findstring $(DISTRIBUTION),hardy intrepid jaunty 
karmic lucid maverick natty oneiric lenny squeeze))
CMAKE_OPTS += -D WITH_INTERNAL_SPATIALITE=FALSE
+else
+   CMAKE_OPTS += -D WITH_INTERNAL_SPATIALITE=TRUE
 endif
 
 ifneq (,$(findstring $(DISTRIBUTION),sid))

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel

[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 3bb9496c99c2415c03c18c2f84d5c96b0a157693
Author: Juergen E. Fischer j...@norbit.de
Date:   Wed Mar 7 07:50:18 2012 +0100

composer api doxygen fixes

diff --git a/src/core/composer/qgscomposeritem.h 
b/src/core/composer/qgscomposeritem.h
index 9f03760..015ad96 100644
--- a/src/core/composer/qgscomposeritem.h
+++ b/src/core/composer/qgscomposeritem.h
@@ -159,33 +159,30 @@ class CORE_EXPORT QgsComposerItem: public QObject, public 
QGraphicsRectItem
 bool _readXML( const QDomElement itemElem, const QDomDocument doc );
 
 /** Whether this item has a frame or not.
- * @param none
  * @return boolean - true if there is a frame around this item, otherwise 
false.
  * @note deprecated since 1.8 dont use!
  * @see hasFrame
  */
-bool frame() const {return hasFrame();}
+Q_DECL_DEPRECATED bool frame() const {return hasFrame();}
 /** Whether this item has a frame or not.
- * @param none
- * @return boolean - true if there is a frame around this item, otherwise 
false.
+ * @returns true if there is a frame around this item, otherwise false.
  * @note introduced since 1.8
  * @see hasFrame
  */
 bool hasFrame() const {return mFrame;}
 /** Set whether this item has a frame drawn around it or not.
- * @param none
- * @return void
+ * @returns void
  * @note deprecated since 1.8 dont use!
  * @see hasFrame
  */
-void setFrame( bool drawFrame ) { setFrameEnabled( drawFrame );}
+Q_DECL_DEPRECATED void setFrame( bool drawFrame ) { setFrameEnabled( 
drawFrame );}
 /** Set whether this item has a frame drawn around it or not.
- * @param none
- * @return void
+ * @param drawFrame draw frame
+ * @returns nothing
  * @note deprecated since 1.8
  * @see hasFrame
  */
-void setFrameEnabled( bool drawFrame ) {mFrame = drawFrame;}
+Q_DECL_DEPRECATED void setFrameEnabled( bool drawFrame ) {mFrame = 
drawFrame;}
 
 /**Composite operations for item groups do nothing per default*/
 virtual void addItem( QgsComposerItem* item ) { Q_UNUSED( item ); }
diff --git a/src/core/composer/qgscomposerlabel.h 
b/src/core/composer/qgscomposerlabel.h
index 2978633..fe1b0b6 100644
--- a/src/core/composer/qgscomposerlabel.h
+++ b/src/core/composer/qgscomposerlabel.h
@@ -47,22 +47,20 @@ class CORE_EXPORT QgsComposerLabel: public QgsComposerItem
 QFont font() const;
 void setFont( const QFont f );
 /** Accessor for the vertical alignment of the label
- * @param none
  * @returns Qt::AlignmentFlag
  */
 Qt::AlignmentFlag vAlign() const { return mVAlignment; }
 /** Accessor for the horizontal alignment of the label
- * @param none
  * @returns Qt::AlignmentFlag
  */
 Qt::AlignmentFlag hAlign() const { return mHAlignment; }
 /** Mutator for the horizontal alignment of the label
- * @param Qt::AlignmentFlag
+ * @param a alignment
  * @returns void
  */
 void setHAlign( Qt::AlignmentFlag a ) {mHAlignment = a;}
 /** Mutator for the vertical alignment of the label
- * @param QQt::AlignmentFlag
+ * @param a alignment
  * @returns void
  */
 void setVAlign( Qt::AlignmentFlag a ) {mVAlignment = a;}

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 6e20c54077baa8b6e5d0bbcc998bbdf279016e3f
Author: Juergen E. Fischer j...@norbit.de
Date:   Wed Mar 7 07:50:44 2012 +0100

catch transformation exceptions in QgsGrassRegionEdit::transform

diff --git a/src/plugins/grass/qgsgrassregion.cpp 
b/src/plugins/grass/qgsgrassregion.cpp
index fe3934a..047a27e 100644
--- a/src/plugins/grass/qgsgrassregion.cpp
+++ b/src/plugins/grass/qgsgrassregion.cpp
@@ -132,14 +132,23 @@ void QgsGrassRegionEdit::setTransform()
 void QgsGrassRegionEdit::transform( QgsMapCanvas *canvas, QVectorQgsPoint 
points, QgsCoordinateTransform *coordinateTransform, 
QgsCoordinateTransform::TransformDirection direction )
 {
   QgsDebugMsg( Entered );
+
   /** Coordinate transform */
   if ( canvas-mapRenderer()-hasCrsTransformEnabled() )
   {
 //QgsDebugMsg ( srcCrs =  +  coordinateTransform-sourceCrs().toWkt() );
 //QgsDebugMsg ( destCrs =  +  coordinateTransform-destCRS().toWkt() );
-for ( int i = 0; i  points.size(); i++ )
+try
+{
+  for ( int i = 0; i  points.size(); i++ )
+  {
+points[i] = coordinateTransform-transform( points[i], direction );
+  }
+}
+catch ( QgsCsException cse )
 {
-  points[i] = coordinateTransform-transform( points[i], direction );
+  Q_UNUSED( cse );
+  QgsDebugMsg( QString( transformation failed: %1 ).arg( cse.what() ) );
 }
   }
 }

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 7a0c6d5b10fe6d24c2876e39955fbff4da917480
Author: Juergen E. Fischer j...@norbit.de
Date:   Wed Mar 7 07:48:36 2012 +0100

debian packaging update: drop hardy, intrepid, jaunty and karmic

diff --git a/debian/changelog b/debian/changelog
index a596437..62a8ac8 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -8,8 +8,9 @@ qgis (1.9.90) UNRELEASED; urgency=low
   * add browser desktop entry
   * add support for Debian wheezy and Ubuntu precise
   * build package with internal libspatialite where libspatialite not available
+  * drop support for Ubuntu hardy, intrepid, jaunty and karmic
 
- -- Jürgen E. Fischer j...@norbit.de  Tue, 06 Mar 2012 20:33:08 +0100
+ -- Jürgen E. Fischer j...@norbit.de  Wed, 07 Mar 2012 06:52:29 +0100
 
 qgis (1.8.0) UNRELEASED; urgency=low
 
diff --git a/debian/compat.hardy b/debian/compat.hardy
deleted file mode 100644
index 7ed6ff8..000
--- a/debian/compat.hardy
+++ /dev/null
@@ -1 +0,0 @@
-5
diff --git a/debian/compat.intrepid b/debian/compat.intrepid
deleted file mode 100644
index 7ed6ff8..000
--- a/debian/compat.intrepid
+++ /dev/null
@@ -1 +0,0 @@
-5
diff --git a/debian/compat.jaunty b/debian/compat.jaunty
deleted file mode 100644
index 7ed6ff8..000
--- a/debian/compat.jaunty
+++ /dev/null
@@ -1 +0,0 @@
-5
diff --git a/debian/compat.karmic b/debian/compat.karmic
deleted file mode 100644
index 7ed6ff8..000
--- a/debian/compat.karmic
+++ /dev/null
@@ -1 +0,0 @@
-5
diff --git a/debian/control.hardy b/debian/control.hardy
deleted file mode 100644
index 8d86e3a..000
--- a/debian/control.hardy
+++ /dev/null
@@ -1,147 +0,0 @@
-Source: qgis
-Section: science
-Priority: extra
-Maintainer: Quantum GIS developers qgis-develo...@lists.osgeo.org
-Build-Depends: debhelper (= 5.0.51~), libgdal1-dev, libpq-dev, 
- libgeos-dev (= 3.0.0), grass-dev, libsqlite3-dev, libgsl0-dev, proj,
- libexpat1-dev, flex, bison, python-dev, cmake (=2.4.3),
- python-sip4 (= 4.5.0), python-central (=0.5), python, sip4 (= 4.5),
- libqt4-core (=4.2.0), libqt4-dev (=4.2.0), libqt4-gui (=4.2.0),
- libqt4-sql (=4.2.0), python-qt4 (=4.1.0), python-qt4-dev (=4.1.0),
- python-sip4-dev (= 4.5.0), pyqt4-dev-tools, fcgi-dev, git-core
-Build-Conflicts: libqgis-dev, qgis-dev
-Standards-Version: 3.8.0
-XS-Python-Version: current
-Homepage: http://qgis.org/
-
-Package: qgis
-Architecture: any
-Depends: ${shlibs:Depends}, ${misc:Depends}, qgis-providers (= 
${binary:Version}), qgis-common (= ${source:Version})
-Recommends: qgis-plugin-grass, python-qgis
-Suggests: gpsbabel
-Conflicts: uim-qt3
-Description: Geographic Information System (GIS)
- A Geographic Information System (GIS) manages, analyzes, and displays
- databases of geographic information. Quantum GIS (QGIS) supports shape file
- viewing and editing, spatial data storage with PostgreSQL/PostGIS, projection
- on-the-fly, map composition, and a number of other features via a plugin
- interface. QGIS also supports display of various georeferenced raster and
- Digital Elevation Model (DEM) formats including GeoTIFF, Arc/Info ASCII Grid,
- and USGS ASCII DEM.
-
-Package: qgis-common
-Architecture: all
-Description: Quantum GIS - architecture-independent data
- Quantum GIS is a Geographic Information System (GIS) which manages, analyzes
- and display databases of geographic information.
- .
- This package contains architecture-independent supporting data files for use 
- with Quantum GIS.
-
-Package: libqgis{QGIS_ABI}
-Architecture: any
-Depends: ${shlibs:Depends}, ${misc:Depends}
-Replaces: qgis (=0.9.2rc1), libqgis-core1, libqgis-gui1, libqgis0, libqgis1
-Description: Quantum GIS - shared libraries
- Quantum GIS is a Geographic Information System (GIS) which manages, analyzes
- and display databases of geographic information.
- .
- This package contains the shared core and gui library that provide an
- interface for plugins and stand-alone applications.
-
-Package: libqgis-dev
-Architecture: any
-Section: libdevel
-Depends: libqgis{QGIS_ABI} (= ${binary:Version}), libgdal1-dev,
- libpq-dev, libgeos-dev (= 3.0.0), grass-dev,
- libsqlite3-dev, libgsl0-dev, proj, libexpat1-dev, libqt4-core (=4.2.0),
- libqt4-dev (=4.2.0), libqt4-gui (=4.2.0), libqt4-qt3support (=4.2.0),
- libqt4-sql (=4.2.0), python-qt4 (=4.1.0), python-qt4-dev (=4.1.0),
- qt4-designer (=4.2.0)
-Provides: qgis-dev
-Replaces: qgis-dev, libqgis1-dev
-Description: Quantum GIS - development files
- Quantum GIS is a Geographic Information System (GIS) which manages, analyzes
- and display databases of geographic information.
- .
- This package contains the headers and libraries needed to develop plugins for
- Quantum GIS.
-
-Package: qgis-plugin-grass
-Architecture: any
-Depends: qgis (= ${binary:Version}), qgis-plugin-grass-common (= 
${source:Version}), ${shlibs:Depends}, ${misc:Depends}
-Description: GRASS plugin for Quantum GIS
- Quantum GIS is a Geographic Information System (GIS) which manages, analyzes

[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 7dc309621829e39fe616c6ebddd85e5a8bd6f8b8
Author: Juergen E. Fischer j...@norbit.de
Date:   Wed Mar 7 20:20:42 2012 +0100

fix #5132

diff --git a/src/core/qgsexpression.cpp b/src/core/qgsexpression.cpp
index d960b3f..5bb7959 100644
--- a/src/core/qgsexpression.cpp
+++ b/src/core/qgsexpression.cpp
@@ -104,7 +104,7 @@ inline bool isNull( const QVariant v ) { return 
v.isNull(); }
 const char* QgsExpression::BinaryOperatorText[] =
 {
   OR, AND,
-  =, , =, =, , , ~, LIKE, ILIKE, IS, IS NOT,
+  =, , =, =, , , ~, LIKE, NOT LIKE, ILIKE, NOT 
ILIKE, IS, IS NOT,
   +, -, *, /, %, ^,
   ||
 };
@@ -722,7 +722,9 @@ QVariant QgsExpression::NodeBinaryOperator::eval( 
QgsExpression* parent, QgsFeat
 
 case boRegexp:
 case boLike:
+case boNotLike:
 case boILike:
+case boNotILike:
   if ( isNull( vL ) || isNull( vR ) )
 return TVL_Unknown;
   else
@@ -731,17 +733,23 @@ QVariant QgsExpression::NodeBinaryOperator::eval( 
QgsExpression* parent, QgsFeat
 QString regexp = getStringValue( vR, parent ); ENSURE_NO_EVAL_ERROR;
 // TODO: cache QRegExp in case that regexp is a literal string (i.e. 
it will stay constant)
 bool matches;
-if ( mOp == boLike || mOp == boILike ) // change from LIKE syntax to 
regexp
+if ( mOp == boLike || mOp == boILike || mOp == boNotLike || mOp == 
boNotILike ) // change from LIKE syntax to regexp
 {
   // XXX escape % and _  ???
   regexp.replace( %, .* );
   regexp.replace( _, . );
-  matches = QRegExp( regexp, mOp == boLike ? Qt::CaseSensitive : 
Qt::CaseInsensitive ).exactMatch( str );
+  matches = QRegExp( regexp, mOp == boLike || mOp == boNotLike ? 
Qt::CaseSensitive : Qt::CaseInsensitive ).exactMatch( str );
 }
 else
 {
   matches = QRegExp( regexp ).indexIn( str ) != -1;
 }
+
+   if( mOp == boNotLike || mOp == boNotILike )
+   {
+ matches = !matches;
+   }
+
 return matches ? TVL_True : TVL_False;
   }
 
diff --git a/src/core/qgsexpression.h b/src/core/qgsexpression.h
index cdd0e6e..4f64f82 100644
--- a/src/core/qgsexpression.h
+++ b/src/core/qgsexpression.h
@@ -149,7 +149,9 @@ class CORE_EXPORT QgsExpression
   boGT,  // 
   boRegexp,
   boLike,
+  boNotLike,
   boILike,
+  boNotILike,
   boIs,
   boIsNot,
 
diff --git a/src/core/qgsexpressionlexer.ll b/src/core/qgsexpressionlexer.ll
index 758c49c..78f1989 100644
--- a/src/core/qgsexpressionlexer.ll
+++ b/src/core/qgsexpressionlexer.ll
@@ -124,12 +124,14 @@ string  '{str_char}*'
{  B_OP(boLT); return LT; }
{  B_OP(boGT); return GT; }
 
-~  { B_OP(boRegexp); return REGEXP; }
-LIKE   { B_OP(boLike); return LIKE; }
-ILIKE  { B_OP(boILike); return ILIKE; }
-IS { B_OP(boIs); return IS; }
-IS NOT { B_OP(boIsNot); return ISNOT; }
-|| { B_OP(boConcat); return CONCAT; }
+~ { B_OP(boRegexp); return REGEXP; }
+LIKE  { B_OP(boLike); return LIKE; }
+NOT LIKE  { B_OP(boNotLike); return LIKE; }
+ILIKE { B_OP(boILike); return LIKE; }
+NOT ILIKE { B_OP(boNotILike); return LIKE; }
+IS{ B_OP(boIs); return IS; }
+IS NOT{ B_OP(boIsNot); return IS; }
+||{ B_OP(boConcat); return CONCAT; }
 
 +  { B_OP(boPlus); return PLUS; }
 -  { B_OP(boMinus); return MINUS; }
diff --git a/src/core/qgsexpressionparser.yy b/src/core/qgsexpressionparser.yy
index 75fa6e6..f96810e 100644
--- a/src/core/qgsexpressionparser.yy
+++ b/src/core/qgsexpressionparser.yy
@@ -74,7 +74,7 @@ QgsExpression::Node* gExpParserRootNode;
 //
 
 // operator tokens
-%token b_op OR AND EQ NE LE GE LT GT REGEXP LIKE ILIKE IS ISNOT PLUS MINUS 
MUL DIV MOD CONCAT POW
+%token b_op OR AND EQ NE LE GE LT GT REGEXP LIKE IS PLUS MINUS MUL DIV MOD 
CONCAT POW
 %token u_op NOT
 %token IN
 
@@ -114,7 +114,7 @@ QgsExpression::Node* gExpParserRootNode;
 %left OR
 %left AND
 %right NOT
-%left EQ NE LE GE LT GT REGEXP LIKE ILIKE IS ISNOT IN
+%left EQ NE LE GE LT GT REGEXP LIKE IS IN
 %left PLUS MINUS
 %left MUL DIV MOD
 %right POW
@@ -134,28 +134,26 @@ root: expression { gExpParserRootNode = $1; }
 ;
 
 expression:
-  expression AND expression{ $$ = BINOP($2, $1, $3); }
-| expression OR expression { $$ = BINOP($2, $1, $3); }
-| expression EQ expression { $$ = BINOP($2, $1, $3); }
-| expression NE expression { $$ = BINOP($2, $1, $3); }
-| expression LE expression { $$ = BINOP($2, $1, $3); }
-| expression GE expression { $$ = BINOP($2, $1, $3); }
-| expression LT expression { $$ = BINOP($2, $1, $3); }
-| expression GT expression { $$ = BINOP($2, $1, $3); }
-| expression REGEXP expression { $$ = BINOP($2, $1, $3); }
-| expression LIKE expression   { $$ = BINOP($2, $1, $3); }
-| expression ILIKE expression  { $$ = BINOP($2, $1, $3); }
-| expression IS expression { $$ = BINOP($2, $1, $3

[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit dabd59b134dfced4aa21671cdc9ab50e7e60d3ba
Author: Juergen E. Fischer j...@norbit.de
Date:   Thu Mar 8 15:55:37 2012 +0100

also build pyspatialite with system spatialite

diff --git a/CMakeLists.txt b/CMakeLists.txt
index ae7a34c..ec4b979 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -61,6 +61,7 @@ SET (WITH_SPATIALITE TRUE CACHE BOOL Determines whether 
SPATIALITE support shou
 
 IF (WITH_SPATIALITE)
   SET (WITH_INTERNAL_SPATIALITE TRUE CACHE BOOL Determines whether SPATIALITE 
support should be built internally)
+  SET (WITH_PYSPATIALITE TRUE CACHE BOOL Determines whether PYSPATIALITE 
should be built)
   IF(WITH_INTERNAL_SPATIALITE)
 SET(SPATIALITE_INCLUDE_DIR ${CMAKE_SOURCE_DIR}/src/core/spatialite/headers)
 SET(HAVE_SPATIALITE TRUE)
diff --git a/python/CMakeLists.txt b/python/CMakeLists.txt
index 89987c3..d0513d3 100644
--- a/python/CMakeLists.txt
+++ b/python/CMakeLists.txt
@@ -3,16 +3,17 @@ ADD_SUBDIRECTORY(plugins)
 SET (PYTHON_OUTPUT_DIRECTORY ${QGIS_OUTPUT_DIRECTORY}/python)
 SET (QGIS_PYTHON_OUTPUT_DIRECTORY ${PYTHON_OUTPUT_DIRECTORY}/qgis)
 
-IF (WITH_INTERNAL_SPATIALITE)
+IF (WITH_PYSPATIALITE)
   ADD_SUBDIRECTORY(pyspatialite)
+ENDIF (WITH_PYSPATIALITE)
 
+IF (WITH_INTERNAL_SPATIALITE)
   INCLUDE_DIRECTORIES(
 ../src/core/spatialite/headers
 ../src/core/spatialite/headers/spatialite
   )
 ENDIF (WITH_INTERNAL_SPATIALITE)
 
-
 SET (CMAKE_RUNTIME_OUTPUT_DIRECTORY ${QGIS_PYTHON_OUTPUT_DIRECTORY})
 SET (CMAKE_LIBRARY_OUTPUT_DIRECTORY ${QGIS_PYTHON_OUTPUT_DIRECTORY})
 
diff --git a/python/pyspatialite/CMakeLists.txt 
b/python/pyspatialite/CMakeLists.txt
index 0d283ee..86a52bd 100644
--- a/python/pyspatialite/CMakeLists.txt
+++ b/python/pyspatialite/CMakeLists.txt
@@ -1,11 +1,14 @@
 SET (CMAKE_RUNTIME_OUTPUT_DIRECTORY ${PYTHON_OUTPUT_DIRECTORY}/pyspatialite)
 SET (CMAKE_LIBRARY_OUTPUT_DIRECTORY ${PYTHON_OUTPUT_DIRECTORY}/pyspatialite)
 
+IF(WITH_INTERNAL_SPATIALITE)
+  INCLUDE_DIRECTORIES(
+../../src/core/spatialite/headers
+../../src/core/spatialite/headers/spatialite
+  )
+ENDIF(WITH_INTERNAL_SPATIALITE)
 
 INCLUDE_DIRECTORIES(
-  ../../src/core/spatialite/headers
-  ../../src/core/spatialite/headers/spatialite
-
   ${PYTHON_INCLUDE_PATH}
   ${GEOS_INCLUDE_DIR}
   ${PROJ_INCLUDE_DIR}

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit a8731244eeef5bed909db16b6fa386e84e50d333
Author: Juergen E. Fischer j...@norbit.de
Date:   Thu Mar 8 16:10:13 2012 +0100

debian packageing update: add globe plugin to ubuntu precise

diff --git a/debian/changelog b/debian/changelog
index 62a8ac8..2eab0bb 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -10,7 +10,7 @@ qgis (1.9.90) UNRELEASED; urgency=low
   * build package with internal libspatialite where libspatialite not available
   * drop support for Ubuntu hardy, intrepid, jaunty and karmic
 
- -- Jürgen E. Fischer j...@norbit.de  Wed, 07 Mar 2012 06:52:29 +0100
+ -- Jürgen E. Fischer j...@norbit.de  Thu, 08 Mar 2012 16:08:09 +0100
 
 qgis (1.8.0) UNRELEASED; urgency=low
 
diff --git a/debian/control.precise b/debian/control.precise
index 5e992e6..1d69bd7 100644
--- a/debian/control.precise
+++ b/debian/control.precise
@@ -30,6 +30,8 @@ Build-Depends:
  python-qt4-dev (=4.1.0),
  python-sip (= 4.5.0),
  python-sip-dev (= 4.5.0),
+ libosgearth-dev,
+ libopenscenegraph-dev,
  git,
  doxygen,
  graphviz,
@@ -42,7 +44,7 @@ Homepage: http://qgis.org/
 Package: qgis
 Architecture: any
 Depends: ${shlibs:Depends}, ${misc:Depends}, qgis-providers (= 
${binary:Version}), qgis-common (= ${source:Version})
-Recommends: qgis-plugin-grass, python-qgis
+Recommends: qgis-plugin-globe, qgis-plugin-grass, python-qgis
 Suggests: gpsbabel
 Conflicts: uim-qt3
 Description: Geographic Information System (GIS)
@@ -197,3 +199,21 @@ Description: Quantum GIS API documentation
  .
  This package contains the Quantum GIS API documentation.
 
+Package: qgis-plugin-globe
+Architecture: any
+Depends: qgis (= ${binary:Version}), qgis-plugin-globe-common (= 
${source:Version}), ${shlibs:Depends}, ${misc:Depends}
+Description: OSG globe plugin for Quantum GIS
+ Quantum GIS is a Geographic Information System (GIS) which manages, analyzes
+ and display databases of geographic information.
+ .
+ This plugin enables 3D viewing using OSG globe in the Quantum GIS.
+
+Package: qgis-plugin-globe-common
+Architecture: all
+Description: OSG GLOBE plugin for Quantum GIS - architecture-independent data
+ Quantum GIS is a Geographic Information System (GIS) which manages, analyzes
+ and display databases of geographic information.
+ .
+ This package contains architecture-independent supporting data files for use
+ with the Quantum GIS GLOBE plugin.
+

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel

[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit f700c01e33ea030bb56e49e6a2d41f7fc6710db6
Author: Juergen E. Fischer j...@norbit.de
Date:   Fri Mar 9 13:30:55 2012 +0100

debian packaging update

diff --git a/debian/control.precise b/debian/control.precise
index 1d69bd7..a39647a 100644
--- a/debian/control.precise
+++ b/debian/control.precise
@@ -16,11 +16,12 @@ Build-Depends:
  libpq-dev,
  libproj-dev,
  libqt4-dev (=4.4.0),
+ libqt4-opengl-dev,
  libqtwebkit-dev,
  libqwt5-qt4-dev,
  libspatialite-dev,
- libspatialindex-dev,
  libsqlite3-dev,
+ libspatialindex-dev,
  pkg-config,
  pyqt4-dev-tools,
  python,
diff --git a/debian/rules b/debian/rules
index 4b8cfd2..8c22725 100755
--- a/debian/rules
+++ b/debian/rules
@@ -165,7 +165,7 @@ binary-arch: build install
install -o root -g root -m 755 $(CURDIR)/debian/qgis.sh 
$(CURDIR)/debian/qgis-plugin-grass/usr/bin/qgis
install -o root -g root -m 755 $(CURDIR)/debian/qgis.sh 
$(CURDIR)/debian/qgis-plugin-grass/usr/bin/qbrowser

-ifneq (,$(findstring $(DISTRIBUTION),sid))
+ifneq (,$(findstring $(DISTRIBUTION),wheezy sid))
dh_python2 --no-guessing-versions
 else
dh_pycentral

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit c6b99909dbe89c98e9557c6bbf9447e98e549f6d
Author: Juergen E. Fischer j...@norbit.de
Date:   Fri Mar 9 17:09:50 2012 +0100

fix typos

diff --git a/python/core/qgscomposeritem.sip b/python/core/qgscomposeritem.sip
index 06e746d..8e1bea7 100644
--- a/python/core/qgscomposeritem.sip
+++ b/python/core/qgscomposeritem.sip
@@ -207,7 +207,7 @@ class QgsComposerItem: QObject, QGraphicsRectItem
 /** Whether this item has a frame or not.
  * @param none
  * @return boolean - true if there is a frame around this item, otherwise 
false.
- * @note deprecated since 1.8 dont use!
+ * @note deprecated since 1.8 don't use!
  * @see hasFrame
  */
 bool frame();
@@ -221,7 +221,7 @@ class QgsComposerItem: QObject, QGraphicsRectItem
 /** Set whether this item has a frame drawn around it or not.
  * @param none
  * @return void
- * @note deprecated since 1.8 dont use!
+ * @note deprecated since 1.8 don't use!
  * @see hasFrame
  */
 void setFrame( bool drawFrame );
@@ -243,7 +243,7 @@ class QgsComposerItem: QObject, QGraphicsRectItem
 //painter down by the same factor for drawing
 
 /**Draws Text. Takes care about all the composer specific issues 
(calculation to pixel, scaling of font and painter
- to work arount the Qt font bug)*/
+ to work around the Qt font bug)*/
 void drawText( QPainter* p, int x, int y, const QString text, const 
QFont font ) const;
 
 /**Like the above, but with a rectangle for multiline text*/
diff --git a/scripts/spelling.dat b/scripts/spelling.dat
index c442eaa..b554b09 100644
--- a/scripts/spelling.dat
+++ b/scripts/spelling.dat
@@ -454,3 +454,5 @@ intersectons:intersections
 secific:specific
 writeable:writable
 vaild:valid
+opps:oops
+arount:around
diff --git a/src/core/composer/qgscomposeritem.h 
b/src/core/composer/qgscomposeritem.h
index 015ad96..a79814e 100644
--- a/src/core/composer/qgscomposeritem.h
+++ b/src/core/composer/qgscomposeritem.h
@@ -160,7 +160,7 @@ class CORE_EXPORT QgsComposerItem: public QObject, public 
QGraphicsRectItem
 
 /** Whether this item has a frame or not.
  * @return boolean - true if there is a frame around this item, otherwise 
false.
- * @note deprecated since 1.8 dont use!
+ * @note deprecated since 1.8 don't use!
  * @see hasFrame
  */
 Q_DECL_DEPRECATED bool frame() const {return hasFrame();}
@@ -172,7 +172,7 @@ class CORE_EXPORT QgsComposerItem: public QObject, public 
QGraphicsRectItem
 bool hasFrame() const {return mFrame;}
 /** Set whether this item has a frame drawn around it or not.
  * @returns void
- * @note deprecated since 1.8 dont use!
+ * @note deprecated since 1.8 don't use!
  * @see hasFrame
  */
 Q_DECL_DEPRECATED void setFrame( bool drawFrame ) { setFrameEnabled( 
drawFrame );}
@@ -202,7 +202,7 @@ class CORE_EXPORT QgsComposerItem: public QObject, public 
QGraphicsRectItem
 //painter down by the same factor for drawing
 
 /**Draws Text. Takes care about all the composer specific issues 
(calculation to pixel, scaling of font and painter
- to work arount the Qt font bug)*/
+ to work around the Qt font bug)*/
 void drawText( QPainter* p, double x, double y, const QString text, const 
QFont font ) const;
 
 /**Like the above, but with a rectangle for multiline text*/

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit ab859598e2e9dcfb5d816e7f7b34841a5cf329d1
Author: Juergen E. Fischer j...@norbit.de
Date:   Fri Mar 9 16:42:53 2012 +0100

fix windows build

diff --git a/src/core/symbology-ng/qgsrendererv2registry.h 
b/src/core/symbology-ng/qgsrendererv2registry.h
index ed274c9..8b304d7 100644
--- a/src/core/symbology-ng/qgsrendererv2registry.h
+++ b/src/core/symbology-ng/qgsrendererv2registry.h
@@ -4,11 +4,11 @@
 #include QIcon
 #include QMap
 #include QStringList
+#include QDomElement
 
 #include qgis.h
 
 class QgsFeatureRendererV2;
-class QDomElement;
 class QgsVectorLayer;
 class QgsStyleV2;
 class QgsRendererV2Widget;

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 2f135c1d630f0f96422547c31a05c38d41997470
Author: Juergen E. Fischer j...@norbit.de
Date:   Fri Mar 9 17:28:06 2012 +0100

use GDAL_FIX_ESRI_WKT in QgsOgrProvider::crs (fixes #5066 with GDAL 1.9)

diff --git a/src/providers/ogr/qgsogrprovider.cpp 
b/src/providers/ogr/qgsogrprovider.cpp
index e428cae..b1054a0 100644
--- a/src/providers/ogr/qgsogrprovider.cpp
+++ b/src/providers/ogr/qgsogrprovider.cpp
@@ -2100,6 +2100,8 @@ QgsCoordinateReferenceSystem QgsOgrProvider::crs()
 }
   }
 
+  CPLSetConfigOption( GDAL_FIX_ESRI_WKT, TOWGS84 ); // add towgs84 
parameter
+
   OGRSpatialReferenceH mySpatialRefSys = OGR_L_GetSpatialRef( ogrLayer );
   if ( mySpatialRefSys )
   {

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit a2b80be89b1d183cfeb69bc019e6fcaddb4bb404
Author: Etienne Tourigny etourigny@gmail.com
Date:   Fri Mar 9 12:13:00 2012 -0300

fixes for browser (GDAL rasters) : skip *.aux.xml files ; add suffix to 
raster file names in browser ; add HDF4 file suffix (.hdf) in 
buildSupportedRasterFileFilterAndExtensions()

diff --git a/src/core/qgsdataitem.cpp b/src/core/qgsdataitem.cpp
index f3ac63e..6cd9ed9 100644
--- a/src/core/qgsdataitem.cpp
+++ b/src/core/qgsdataitem.cpp
@@ -194,7 +194,8 @@ bool QgsDataItem::hasChildren()
 
 void QgsDataItem::addChildItem( QgsDataItem * child, bool refresh )
 {
-  QgsDebugMsg( mName =  + child-mName );
+  QgsDebugMsg( QString( add child #%1 - %2 ).arg( mChildren.size() ).arg( 
child-mName ) );
+
   int i;
   for ( i = 0; i  mChildren.size(); i++ )
   {
diff --git a/src/providers/gdal/qgsgdaldataitems.cpp 
b/src/providers/gdal/qgsgdaldataitems.cpp
index f2901c6..146f80d 100644
--- a/src/providers/gdal/qgsgdaldataitems.cpp
+++ b/src/providers/gdal/qgsgdaldataitems.cpp
@@ -79,6 +79,12 @@ QGISEXTERN QgsDataItem * dataItem( QString thePath, 
QgsDataItem* parentItem )
   QgsDebugMsg( extensions:  + extensions.join(   ) );
   QgsDebugMsg( wildcards:  + wildcards.join(   ) );
 }
+// skip *.aux.xml files (GDAL auxilary metadata files)
+// unless that extension is in the list (*.xml might be though)
+if ( thePath.right( 8 ) == .aux.xml 
+ extensions.indexOf( aux.xml )  0 )
+  return 0;
+
 if ( extensions.indexOf( info.suffix().toLower() )  0 )
 {
   bool matches = false;
@@ -107,7 +113,8 @@ QGISEXTERN QgsDataItem * dataItem( QString thePath, 
QgsDataItem* parentItem )
 
 QgsDebugMsg( GdalDataset opened  + thePath );
 
-QString name = info.completeBaseName();
+//extract basename with extension
+QString name = info.completeBaseName() + . + QFileInfo( thePath 
).suffix();
 QString uri = thePath;
 
 QgsLayerItem * item = new QgsGdalLayerItem( parentItem, name, thePath, uri 
);
@@ -124,11 +131,10 @@ QGISEXTERN QgsDataItem * dataItem( QString thePath, 
QgsDataItem* parentItem )
 if ( hChildDS )
 {
   GDALClose( hChildDS );
-  QgsDebugMsg( QString( add child #%1 - %2 ).arg( i ).arg( 
sublayers[i] ) );
 
   QString name = sublayers[i];
-  name.replace( thePath, QFileInfo( thePath ).completeBaseName() );
-
+  //replace full path with basename+extension
+  name.replace( thePath, QFileInfo( thePath ).completeBaseName() + . 
+ QFileInfo( thePath ).suffix() );
   childItem = new QgsGdalLayerItem( item, name, thePath + / + name, 
sublayers[i] );
   if ( childItem )
 item-addChildItem( childItem );
diff --git a/src/providers/gdal/qgsgdalprovider.cpp 
b/src/providers/gdal/qgsgdalprovider.cpp
index a23b82f..d8f3b24 100644
--- a/src/providers/gdal/qgsgdalprovider.cpp
+++ b/src/providers/gdal/qgsgdalprovider.cpp
@@ -1267,7 +1267,10 @@ QStringList QgsGdalProvider::subLayers( GDALDatasetH 
dataset )
 }
   }
 
-  QgsDebugMsg( sublayers:\n   + subLayers.join( \n   ) );
+  if ( subLayers.size()  0 )
+  {
+QgsDebugMsg( sublayers:\n   + subLayers.join( \n   ) );
+  }
 
   return subLayers;
 }
@@ -1801,6 +1804,13 @@ void buildSupportedRasterFileFilterAndExtensions( 
QString  theFileFiltersString
 theFileFiltersString += ;;[GDAL]  + myGdalDriverLongName +  ( + 
glob.toLower() +   + glob.toUpper() + );
 theWildcards  hdr.adf;
   }
+  else if ( myGdalDriverDescription == HDF4 )
+  {
+// HDF4 extension missing in driver metadata
+QString glob = *.hdf;
+theFileFiltersString += ;;[GDAL]  + myGdalDriverLongName +  ( + 
glob.toLower() +   + glob.toUpper() + );
+theExtensions  hdf;
+  }
   else
   {
 catchallFilter  QString( GDALGetDescription( myGdalDriver ) );

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 227263928f96e382f96b4abbb6651bf87076a34a
Author: Etienne Tourigny etourigny@gmail.com
Date:   Fri Mar 9 15:37:22 2012 -0300

browser dock: add selected layers via context menu and tool button

diff --git a/src/app/qgsbrowserdockwidget.cpp b/src/app/qgsbrowserdockwidget.cpp
index 681a183..15815df 100644
--- a/src/app/qgsbrowserdockwidget.cpp
+++ b/src/app/qgsbrowserdockwidget.cpp
@@ -68,16 +68,35 @@ QgsBrowserDockWidget::QgsBrowserDockWidget( QWidget * 
parent ) :
 
   mBrowserView = new QgsBrowserTreeView( this );
 
-  mRefreshButton = new QToolButton( this );
-  mRefreshButton-setIcon( QgisApp::instance()-getThemeIcon( 
mActionDraw.png ) );
-  mRefreshButton-setText( tr( Refresh ) );
-  mRefreshButton-setAutoRaise( true );
-  connect( mRefreshButton, SIGNAL( clicked() ), this, SLOT( refresh() ) );
+  QToolButton* refreshButton = new QToolButton( this );
+  refreshButton-setIcon( QgisApp::instance()-getThemeIcon( mActionDraw.png 
) );
+  // remove this to save space
+  refreshButton-setToolButtonStyle( Qt::ToolButtonTextBesideIcon );
+  refreshButton-setText( tr( Refresh ) );
+  refreshButton-setToolTip( tr( Refresh ) );
+  refreshButton-setAutoRaise( true );
+  connect( refreshButton, SIGNAL( clicked() ), this, SLOT( refresh() ) );
+
+  QToolButton* addLayersButton = new QToolButton( this );
+  addLayersButton-setIcon( QgisApp::instance()-getThemeIcon( 
mActionAddLayer.png ) );
+  // remove this to save space
+  addLayersButton-setToolButtonStyle( Qt::ToolButtonTextBesideIcon );
+  addLayersButton-setText( tr( Add Selection ) );
+  addLayersButton-setToolTip( tr( Add Selected Layers ) );
+  addLayersButton-setAutoRaise( true );
+  connect( addLayersButton, SIGNAL( clicked() ), this, SLOT( 
addSelectedLayers() ) );
 
   QVBoxLayout* layout = new QVBoxLayout();
+  QHBoxLayout* hlayout = new QHBoxLayout();
   layout-setContentsMargins( 0, 0, 0, 0 );
   layout-setSpacing( 0 );
-  layout-addWidget( mRefreshButton );
+  hlayout-setContentsMargins( 0, 0, 0, 0 );
+  hlayout-setSpacing( 5 );
+  hlayout-setAlignment( Qt::AlignLeft );
+
+  hlayout-addWidget( refreshButton );
+  hlayout-addWidget( addLayersButton );
+  layout-addLayout( hlayout );
   layout-addWidget( mBrowserView );
 
   QWidget* innerWidget = new QWidget( this );
@@ -110,55 +129,13 @@ void QgsBrowserDockWidget::showEvent( QShowEvent * e )
 
 void QgsBrowserDockWidget::itemClicked( const QModelIndex index )
 {
-  QgsDataItem *item = mModel-dataItem( index );
-  if ( !item )
-return;
-
-  QgsLayerItem *layerItem = qobject_castQgsLayerItem*( mModel-dataItem( 
index ) );
-  if ( layerItem == NULL )
-return;
-
-  QString uri = layerItem-uri();
-  if ( uri.isEmpty() )
-return;
+  QgsDataItem *dataItem = mModel-dataItem( index );
 
-  QgsMapLayer::LayerType type = layerItem-mapLayerType();
-  QString providerKey = layerItem-providerKey();
-
-  QgsDebugMsg( providerKey +  :  + uri );
-  if ( type == QgsMapLayer::VectorLayer )
+  if ( dataItem != NULL  dataItem-type() == QgsDataItem::Layer )
   {
-QgisApp::instance()-addVectorLayer( uri, layerItem-name(), providerKey );
-  }
-  if ( type == QgsMapLayer::RasterLayer )
-  {
-// This should go to WMS provider
-QStringList URIParts = uri.split( | );
-QString rasterLayerPath = URIParts.at( 0 );
-QStringList layers;
-QStringList styles;
-QString format;
-QString crs;
-for ( int i = 1 ; i  URIParts.size(); i++ )
-{
-  QString part = URIParts.at( i );
-  int pos = part.indexOf( = );
-  QString field = part.left( pos );
-  QString value = part.mid( pos + 1 );
-
-  if ( field == layers )
-layers = value.split( , );
-  if ( field == styles )
-styles = value.split( , );
-  if ( field == format )
-format = value;
-  if ( field == crs )
-crs = value;
-}
-QgsDebugMsg( rasterLayerPath =  + rasterLayerPath );
-QgsDebugMsg( layers =  + layers.join(   ) );
-
-QgisApp::instance()-addRasterLayer( rasterLayerPath, layerItem-name(), 
providerKey, layers, styles, format, crs );
+QgsLayerItem *layerItem = qobject_castQgsLayerItem*( dataItem );
+if ( layerItem != NULL )
+  addLayer( layerItem );
   }
 }
 
@@ -189,6 +166,12 @@ void QgsBrowserDockWidget::showContextMenu( const QPoint  
pt )
 }
   }
 
+  else if ( item-type() == QgsDataItem::Layer )
+  {
+menu-addAction( tr( Add Layer ), this, SLOT( itemClicked( idx ) ) );
+menu-addAction( tr( Add Selected Layers ), this, SLOT( 
addSelectedLayers() ) );
+  }
+
   QListQAction* actions = item-actions();
   if ( !actions.isEmpty() )
   {
@@ -279,3 +262,76 @@ void QgsBrowserDockWidget::refreshModel( const 
QModelIndex index )
 }
   }
 }
+
+void QgsBrowserDockWidget::addLayer( QgsLayerItem *layerItem )
+{
+  if ( layerItem == NULL )
+return;
+
+  QString uri = layerItem-uri();
+  if ( uri.isEmpty() )
+return;
+
+  QgsMapLayer::LayerType type = 

[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit d8c8a6768f43614ac099a9a0dfeb610ed26527e2
Author: Etienne Tourigny etourigny@gmail.com
Date:   Fri Mar 9 10:30:53 2012 -0300

QgisApp::askUserForGDALSublayers : fix order of new layers in the layers 
dock ; add an option to load all sublayers of a GDAL raster with subdatasets

diff --git a/src/app/qgisapp.cpp b/src/app/qgisapp.cpp
index dd6ee6c..5c28856 100644
--- a/src/app/qgisapp.cpp
+++ b/src/app/qgisapp.cpp
@@ -2262,15 +2262,23 @@ bool QgisApp::addVectorLayers( QStringList const  
theLayerQStringList, const QS
   return true;
 } // QgisApp::addVectorLayer()
 
+// present a dialog to choose GDAL raster sublayers
 void QgisApp::askUserForGDALSublayers( QgsRasterLayer *layer )
 {
-  if ( !layer )
+  if ( !layer || layer-subLayers().size()  1 )
 return;
 
   QStringList sublayers = layer-subLayers();
-
   QgsDebugMsg( sublayers:\n   + sublayers.join(   \n ) + \n );
 
+  // if promptLayers=Load all, load all sublayers without prompting
+  QSettings settings;
+  if ( settings.value( /qgis/promptForRasterSublayers, 1 ).toInt() == 3 )
+  {
+loadGDALSublayers( layer-source(), sublayers );
+return;
+  }
+
   // We initialize a selection dialog and display it.
   QgsOGRSublayersDialog chooseSublayersDialog( this );
   chooseSublayersDialog.setWindowTitle( tr( Select raster layers to add... ) 
);
@@ -2285,19 +2293,11 @@ void QgisApp::askUserForGDALSublayers( QgsRasterLayer 
*layer )
 
   if ( chooseSublayersDialog.exec() )
   {
-foreach( QString path, chooseSublayersDialog.getSelection() )
-{
-  QString name = path;
-  name.replace( layer-source(), QFileInfo( layer-source() 
).completeBaseName() );
-  QgsRasterLayer *rlayer = new QgsRasterLayer( path, name );
-  if ( rlayer  rlayer-isValid() )
-  {
-addRasterLayer( rlayer );
-  }
-}
+loadGDALSublayers( layer-source(), chooseSublayersDialog.getSelection() );
   }
 }
 
+// should the GDAL sublayers dialog should be presented to the user?
 bool QgisApp::shouldAskUserForGDALSublayers( QgsRasterLayer *layer )
 {
   // return false if layer is empty or raster has no sublayers
@@ -2306,13 +2306,35 @@ bool QgisApp::shouldAskUserForGDALSublayers( 
QgsRasterLayer *layer )
 
   QSettings settings;
   int promptLayers = settings.value( /qgis/promptForRasterSublayers, 1 
).toInt();
-  // 0 = always - always ask (if there are existing sublayers)
-  // 1 = if needed - ask if layer has no bands, but has sublayers
-  // 2 = never
 
-  return promptLayers == 0 || ( promptLayers == 1  layer-bandCount() == 0 );
+  // return true if promptLayers=Always or if promptLayers!=Never and there 
are no bands
+  return promptLayers == 0 || ( promptLayers != 2  layer-bandCount() == 0 );
 }
 
+// This method will load with GDAL the layers in parameter.
+// It is normally triggered by the sublayer selection dialog.
+void QgisApp::loadGDALSublayers( QString uri, QStringList list )
+{
+  QString path, name;
+  QgsRasterLayer *subLayer = NULL;
+
+  //add layers in reverse order so they appear in the right order in the layer 
dock
+  for ( int i = list.size() - 1; i = 0 ; i-- )
+  {
+path = list[i];
+// shorten name by replacing complete path with filename
+name = path;
+name.replace( uri, QFileInfo( uri ).completeBaseName() );
+subLayer = new QgsRasterLayer( path, name );
+if ( subLayer )
+{
+  if ( subLayer-isValid() )
+addRasterLayer( subLayer );
+  else
+delete subLayer;
+}
+  }
+}
 
 // This method is the method that does the real job. If the layer given in
 // parameter is NULL, then the method tries to act on the activeLayer.
diff --git a/src/app/qgisapp.h b/src/app/qgisapp.h
index c56828b..8b54096 100644
--- a/src/app/qgisapp.h
+++ b/src/app/qgisapp.h
@@ -422,6 +422,7 @@ class QgisApp : public QMainWindow, private Ui::MainWindow
 void editPaste( QgsMapLayer * destinationLayer = 0 );
 
 void loadOGRSublayers( QString layertype, QString uri, QStringList list );
+void loadGDALSublayers( QString uri, QStringList list );
 
 /**Deletes the selected attributes for the currently selected vector 
layer*/
 void deleteSelected( QgsMapLayer *layer = 0, QWidget* parent = 0 );
diff --git a/src/app/qgsoptions.cpp b/src/app/qgsoptions.cpp
index 40234f3..dc49ff8 100644
--- a/src/app/qgsoptions.cpp
+++ b/src/app/qgsoptions.cpp
@@ -185,10 +185,15 @@ QgsOptions::QgsOptions( QWidget *parent, Qt::WFlags fl ) :
   spinBoxAttrTableRowCache-setValue( settings.value( 
/qgis/attributeTableRowCache, 1 ).toInt() );
 
   // set the prompt for raster sublayers
+  // 0 = Always - always ask (if there are existing sublayers)
+  // 1 = If needed - ask if layer has no bands, but has sublayers
+  // 2 = Never - never prompt, will not load anything
+  // 4 = Load all - never prompt, but load all sublayers
   cmbPromptRasterSublayers-clear();
   cmbPromptRasterSublayers-addItem( tr( Always ) );
   

[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 892cc39a8a970539158c8f382a5a4c2ade346eb8
Author: Juergen E. Fischer j...@norbit.de
Date:   Fri Mar 9 22:56:06 2012 +0100

remove geoimage austria wms server

diff --git a/src/providers/wms/qgswmssourceselect.cpp 
b/src/providers/wms/qgswmssourceselect.cpp
index b5c06e3..08c2fbd 100644
--- a/src/providers/wms/qgswmssourceselect.cpp
+++ b/src/providers/wms/qgswmssourceselect.cpp
@@ -990,7 +990,6 @@ void QgsWMSSourceSelect::addDefaultServers()
   QMapQString, QString exampleServers;
   exampleServers[DM Solutions GMap] = 
http://www2.dmsolutions.ca/cgi-bin/mswms_gmap;;
   exampleServers[Lizardtech server] =  
http://wms.lizardtech.com/lizardtech/iserv/ows;;
-  exampleServers[GEOIMAGE-AUSTRIA] =  http://wms.geoimage.at/dop-1mfree?;;
   // Nice to have the qgis users map, but I'm not sure of the URL at the 
moment.
   //  exampleServers[Qgis users map] = http://qgis.org/wms.cgi;;
 

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 5f771a6ffe0a3d0d133190a9af77e6c5c91a328a
Author: Juergen E. Fischer j...@norbit.de
Date:   Mon Mar 12 22:47:12 2012 +0100

fix QgsComposerItem API

diff --git a/python/core/qgscomposeritem.sip b/python/core/qgscomposeritem.sip
index 8e1bea7..ae74cf9 100644
--- a/python/core/qgscomposeritem.sip
+++ b/python/core/qgscomposeritem.sip
@@ -222,13 +222,13 @@ class QgsComposerItem: QObject, QGraphicsRectItem
  * @param none
  * @return void
  * @note deprecated since 1.8 don't use!
- * @see hasFrame
+ * @see setFrameEnabled
  */
 void setFrame( bool drawFrame );
 /** Set whether this item has a frame drawn around it or not.
  * @param none
  * @return void
- * @note deprecated since 1.8
+ * @note introduced in 1.8
  * @see hasFrame
  */
 void setFrameEnabled( bool drawFrame );
diff --git a/src/app/composer/qgscomposeritemwidget.cpp 
b/src/app/composer/qgscomposeritemwidget.cpp
index 6b560c3..5cc65cc 100644
--- a/src/app/composer/qgscomposeritemwidget.cpp
+++ b/src/app/composer/qgscomposeritemwidget.cpp
@@ -130,11 +130,11 @@ void 
QgsComposerItemWidget::on_mFrameCheckBox_stateChanged( int state )
   mItem-beginCommand( tr( Item frame toggled ) );
   if ( state == Qt::Checked )
   {
-mItem-setFrame( true );
+mItem-setFrameEnabled( true );
   }
   else
   {
-mItem-setFrame( false );
+mItem-setFrameEnabled( false );
   }
   mItem-update();
   mItem-endCommand();
@@ -155,7 +155,7 @@ void QgsComposerItemWidget::setValuesForGuiElements()
   mOpacitySlider-setValue( mItem-brush().color().alpha() );
   mOutlineWidthSpinBox-setValue( mItem-pen().widthF() );
   mItemIdLineEdit-setText( mItem-id() );
-  if ( mItem-frame() )
+  if ( mItem-hasFrame() )
   {
 mFrameCheckBox-setCheckState( Qt::Checked );
   }
diff --git a/src/core/composer/qgscomposeritem.h 
b/src/core/composer/qgscomposeritem.h
index a79814e..df46466 100644
--- a/src/core/composer/qgscomposeritem.h
+++ b/src/core/composer/qgscomposeritem.h
@@ -167,22 +167,21 @@ class CORE_EXPORT QgsComposerItem: public QObject, public 
QGraphicsRectItem
 /** Whether this item has a frame or not.
  * @returns true if there is a frame around this item, otherwise false.
  * @note introduced since 1.8
- * @see hasFrame
  */
 bool hasFrame() const {return mFrame;}
 /** Set whether this item has a frame drawn around it or not.
  * @returns void
  * @note deprecated since 1.8 don't use!
- * @see hasFrame
+ * @see setFrameEnabled
  */
 Q_DECL_DEPRECATED void setFrame( bool drawFrame ) { setFrameEnabled( 
drawFrame );}
 /** Set whether this item has a frame drawn around it or not.
  * @param drawFrame draw frame
  * @returns nothing
- * @note deprecated since 1.8
+ * @note introduced in 1.8
  * @see hasFrame
  */
-Q_DECL_DEPRECATED void setFrameEnabled( bool drawFrame ) {mFrame = 
drawFrame;}
+void setFrameEnabled( bool drawFrame ) {mFrame = drawFrame;}
 
 /**Composite operations for item groups do nothing per default*/
 virtual void addItem( QgsComposerItem* item ) { Q_UNUSED( item ); }
diff --git a/src/plugins/georeferencer/qgsgeorefplugingui.cpp 
b/src/plugins/georeferencer/qgsgeorefplugingui.cpp
index b6532bd..992aba2 100644
--- a/src/plugins/georeferencer/qgsgeorefplugingui.cpp
+++ b/src/plugins/georeferencer/qgsgeorefplugingui.cpp
@@ -1494,7 +1494,7 @@ bool QgsGeorefPluginGui::writePDFReportFile( const 
QString fileName, const QgsG
   titleLabel-setText( rasterFi.fileName() );
   composition-addItem( titleLabel );
   titleLabel-setSceneRect( QRectF( leftMargin, 5, contentWidth, 8 ) );
-  titleLabel-setFrame( false );
+  titleLabel-setFrameEnabled( false );
 
   //composer map
   QgsRectangle canvasExtent = mCanvas-extent();
@@ -1549,7 +1549,7 @@ bool QgsGeorefPluginGui::writePDFReportFile( const 
QString fileName, const QgsG
 parameterLabel-adjustSizeToText();
 composition-addItem( parameterLabel );
 parameterLabel-setSceneRect( QRectF( leftMargin, 
composerMap-rect().bottom() + composerMap-transform().dy() + 5, contentWidth, 
8 ) );
-parameterLabel-setFrame( false );
+parameterLabel-setFrameEnabled( false );
 
 //calculate mean error
 double meanError = 0;
@@ -1581,7 +1581,7 @@ bool QgsGeorefPluginGui::writePDFReportFile( const 
QString fileName, const QgsG
   residualLabel-setText( tr( Residuals ) );
   composition-addItem( residualLabel );
   residualLabel-setSceneRect( QRectF( leftMargin, 
previousItem-rect().bottom() + previousItem-transform().dy() + 5, 
contentWidth, 6 ) );
-  residualLabel-setFrame( false );
+  residualLabel-setFrameEnabled( false );
 
   //residual plot
   QgsResidualPlotItem* resPlotItem = new QgsResidualPlotItem( composition );

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org

[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 533ac4c4ca776e18ff6d1a9154d72391b76c5f7e
Author: Juergen E. Fischer j...@norbit.de
Date:   Mon Mar 12 22:48:01 2012 +0100

fix crash on quit

diff --git a/src/app/qgisapp.cpp b/src/app/qgisapp.cpp
index 5c28856..05e18d1 100644
--- a/src/app/qgisapp.cpp
+++ b/src/app/qgisapp.cpp
@@ -1679,6 +1679,7 @@ void QgisApp::createCanvasTools()
 #else
   mAdvancedDigitizeToolBar-removeAction( mActionOffsetCurve );
   mEditMenu-removeAction( mActionOffsetCurve );
+  mMapTools.mOffsetCurve = 0;
 #endif //GEOS_VERSION
   mMapTools.mReshapeFeatures = new QgsMapToolReshape( mMapCanvas );
   mMapTools.mReshapeFeatures-setAction( mActionReshapeFeatures );
diff --git a/src/gui/qgsexpressionbuilderwidget.cpp 
b/src/gui/qgsexpressionbuilderwidget.cpp
index 28efa28..d3e23a7 100644
--- a/src/gui/qgsexpressionbuilderwidget.cpp
+++ b/src/gui/qgsexpressionbuilderwidget.cpp
@@ -415,7 +415,7 @@ QString QgsExpressionBuilderWidget::loadFunctionHelp( 
QgsExpressionItem* functio
 
   QString missingError = tr( h3Oops! QGIS can't find help for this 
function./h3
  The help file for %1 was not found.br
-   
 ).arg( Qt::escape( name ) );
+   ).arg( Qt::escape( name ) );
 
   if ( !lang.startsWith( en_ ) )
   {

-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 949b2f0179f7d4fd1ef61856fd8ed9dc366a87ae
Author: Juergen E. Fischer j...@norbit.de
Date:   Thu Mar 15 23:59:33 2012 +0100

WMS 1.3: better detection of inverted axis

diff --git a/src/core/qgscoordinatereferencesystem.cpp 
b/src/core/qgscoordinatereferencesystem.cpp
index 5fb2631..4a0fbc9 100644
--- a/src/core/qgscoordinatereferencesystem.cpp
+++ b/src/core/qgscoordinatereferencesystem.cpp
@@ -166,6 +166,7 @@ QgsCoordinateReferenceSystem 
QgsCoordinateReferenceSystem::operator=( const Qgs
 mProjectionAcronym = srs.mProjectionAcronym;
 mEllipsoidAcronym = srs.mEllipsoidAcronym;
 mGeoFlag = srs.mGeoFlag;
+mAxisInverted = srs.mAxisInverted;
 mMapUnits = srs.mMapUnits;
 mSRID = srs.mSRID;
 mAuthId = srs.mAuthId;
@@ -264,6 +265,7 @@ bool QgsCoordinateReferenceSystem::loadFromDb( QString db, 
QString expression, Q
 mSRID = QString::fromUtf8(( char * )sqlite3_column_text( 
myPreparedStatement, 5 ) ).toLong();
 mAuthId = QString::fromUtf8(( char * )sqlite3_column_text( 
myPreparedStatement, 6 ) );
 mGeoFlag = QString::fromUtf8(( char * )sqlite3_column_text( 
myPreparedStatement, 7 ) ).toInt() != 0;
+mAxisInverted = -1;
 
 if ( mSrsId = USER_CRS_START_ID  mAuthId.isEmpty() )
 {
@@ -291,6 +293,21 @@ bool QgsCoordinateReferenceSystem::loadFromDb( QString db, 
QString expression, Q
   return mIsValidFlag;
 }
 
+bool QgsCoordinateReferenceSystem::axisInverted() const
+{
+  if ( mAxisInverted == -1 )
+  {
+OGRAxisOrientation orientation;
+const char *axis0 = OSRGetAxis( mCRS, mGeoFlag ? GEOGCS : PROJCS, 0, 
orientation );
+mAxisInverted = mGeoFlag
+  ? (orientation == OAO_East || orientation == OAO_West || 
orientation == OAO_Other )
+  : (orientation == OAO_North || orientation == OAO_South );
+QgsDebugMsg( QString( srid:%1 axis0:%2 orientation:%3 inverted:%4 ).arg( 
mSRID ).arg( axis0 ).arg( OSRAxisEnumToName( orientation ) ).arg( mAxisInverted 
) );
+  }
+
+  return mAxisInverted != 0;
+}
+
 bool QgsCoordinateReferenceSystem::createFromWkt( QString theWkt )
 {
   mIsValidFlag = false;
diff --git a/src/core/qgscoordinatereferencesystem.h 
b/src/core/qgscoordinatereferencesystem.h
index b40e490..91965e1 100644
--- a/src/core/qgscoordinatereferencesystem.h
+++ b/src/core/qgscoordinatereferencesystem.h
@@ -308,6 +308,12 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
  */
 bool geographicFlag() const;
 
+/*! return if axis is inverted (eg. for WMS 1.3)
+ * @return  bool Whether this is crs axis is inverted
+ * @note added in 1.9.90
+ */
+bool axisInverted() const;
+
 /*! Get the units that the projection is in
  * @return QGis::UnitType that gives the units for the coordinate system
  */
@@ -434,6 +440,9 @@ class CORE_EXPORT QgsCoordinateReferenceSystem
 QString mValidationHint;
 mutable QString mWkt;
 
+//!Whether this is a coordinate system has inverted axis
+mutable int mAxisInverted;
+
 static CUSTOM_CRS_VALIDATION mCustomSrsValidation;
 };
 
diff --git a/src/mapserver/qgsconfigparser.cpp 
b/src/mapserver/qgsconfigparser.cpp
index a726210..0d2ec15 100644
--- a/src/mapserver/qgsconfigparser.cpp
+++ b/src/mapserver/qgsconfigparser.cpp
@@ -444,11 +444,11 @@ QgsComposition* QgsConfigParser::createPrintComposition( 
const QString composer
   c-removeItem( currentMap ); delete currentMap; continue;
 }
 
-//Change x- and y- of extent for WMS 1.3.0 and geographic coordinate 
systems
+//Change x- and y- of extent for WMS 1.3.0 if axis inverted
 QString version = parameterMap.value( VERSION );
 if ( !version.isEmpty() )
 {
-  if ( mapRenderer  version == 1.3.0  
mapRenderer-destinationCrs().geographicFlag() )
+  if ( mapRenderer  version == 1.3.0  
mapRenderer-destinationCrs().axisInverted() )
   {
 //switch coordinates of extent
 double tmp;
diff --git a/src/providers/wms/qgswmsprovider.cpp 
b/src/providers/wms/qgswmsprovider.cpp
index d50ff57..671f79e 100644
--- a/src/providers/wms/qgswmsprovider.cpp
+++ b/src/providers/wms/qgswmsprovider.cpp
@@ -415,13 +415,13 @@ QImage *QgsWmsProvider::draw( QgsRectangle  const 
viewExtent, int pixelWidth, i

[SCM] qgis branch, master, updated. a2ee769957385f4e084c5e8b6ba178a8c877d1db

2012-03-20 Thread Juergen E. Fischer
The following commit has been merged in the master branch:
commit 6972cfa2b09dcbcd4df1daf43fd9bd01861a957b
Author: Juergen E. Fischer j...@norbit.de
Date:   Mon Mar 19 08:25:07 2012 +0100

apply #5121

diff --git a/src/app/gps/qgsgpsinformationwidget.cpp 
b/src/app/gps/qgsgpsinformationwidget.cpp
index a01a997..d0ec1ba 100644
--- a/src/app/gps/qgsgpsinformationwidget.cpp
+++ b/src/app/gps/qgsgpsinformationwidget.cpp
@@ -390,7 +390,7 @@ void QgsGPSInformationWidget::connectGps()
 
   if ( mRadUserPath-isChecked() )
   {
-port = mCboDevices-currentText();
+port = mCboDevices-itemData( mCboDevices-currentIndex() ).toString();
 
 if ( port.isEmpty() )
 {

diff --git a/src/mapserver/qgswmsserver.cpp b/src/mapserver/qgswmsserver.cpp
index 637c02a..1de6a91 100644
--- a/src/mapserver/qgswmsserver.cpp
+++ b/src/mapserver/qgswmsserver.cpp
@@ -1120,9 +1120,9 @@ int QgsWMSServer::configureMapRender( const QPaintDevice* 
paintDevice ) const
   }
   mMapRenderer-setMapUnits( mapUnits );
 
   // Change x- and y- of BBOX for WMS 1.3.0 and geographic coordinate systems
   QString version = mParameterMap.value( VERSION, 1.3.0 );
-  if ( version == 1.3.0  outputCRS.geographicFlag() )
+  if ( version == 1.3.0  outputCRS.axisInverted() )
   {
 //switch coordinates of extent
 double tmp;
@@ -1120,9 +1120,9 @@ int QgsWMSServer::configureMapRender( const QPaintDevice* 
   mMapRenderer-setMapUnits( mapUnits );
 
-  // Change x- and y- of BBOX for WMS 1.3.0 and geographic coordinate systems
+  // Change x- and y- of BBOX for WMS 1.3.0 if axis inverted
   QString version = mParameterMap.value( VERSION, 1.3.0 );
-- 
The Quantum GIS in Debian project

___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-grass-devel


[DebianGIS-dev] Bug#563255: grass: locale missing

2010-01-01 Thread Juergen E. Fischer
Package: grass
Version: 6.4.0~rc5+40109-1
Severity: normal

Hi,

usr/lib/grass64/locale is missing from debian/grass.install.  Therefore
G_gettext() didn't work as expected.


Juergen


-- System Information:
Debian Release: squeeze/sid
  APT prefers unstable
  APT policy: (500, 'unstable')
Architecture: amd64 (x86_64)

Kernel: Linux 2.6.32.2-elrond (SMP w/4 CPU cores)
Locale: LANG=C, LC_CTYPE=C (charmap=ANSI_X3.4-1968)
Shell: /bin/sh linked to /bin/bash

Versions of packages grass depends on:
ii  aterm [x-terminal-emul 1.0.1-7   Afterstep XVT - a VT102 emulator f
ii  gnome-terminal [x-term 2.28.2-1  The GNOME terminal emulator applic
ii  lesstif2   1:0.95.2-1OSF/Motif 2.1 implementation relea
ii  libc6  2.10.2-2  GNU C Library: Shared libraries
ii  libcairo2  1.8.8-2   The Cairo 2D vector graphics libra
ii  libfftw3-3 3.2.2-1   library for computing Fast Fourier
ii  libfontconfig1 2.6.0-4.2 generic font configuration library
ii  libfreetype6   2.3.11-1  FreeType 2 font engine, shared lib
ii  libgcc11:4.4.2-6 GCC support library
ii  libgdal1-1.6.0 1.6.3-1   Geospatial Data Abstraction Librar
ii  libgl1-mesa-glx [libgl 7.6.1~rc3-1   A free implementation of the OpenG
ii  libglu1-mesa [libglu1] 7.6.1~rc3-1   The OpenGL utility library (GLU)
ii  libice62:1.0.6-1 X11 Inter-Client Exchange library
ii  libmysqlclient16   5.1.41-3  MySQL database client library
ii  libncurses55.7+20090803-2shared libraries for terminal hand
ii  libpng12-0 1.2.41-1  PNG library - runtime
ii  libpq5 8.4.2-1   PostgreSQL C client library
ii  libproj0   4.7.0-1   Cartographic projection library
ii  libreadline6   6.0-5 GNU readline and history libraries
ii  libsm6 2:1.1.1-1 X11 Session Management library
ii  libsqlite3-0   3.6.21-2  SQLite 3 shared library
ii  libstdc++6 4.4.2-6   The GNU Standard C++ Library v3
ii  libtiff4   3.9.2-1   Tag Image File Format (TIFF) libra
ii  libwxbase2.8-0 2.8.10.1-2wxBase library (runtime) - non-GUI
ii  libwxgtk2.8-0  2.8.10.1-2wxWidgets Cross-platform C++ GUI t
ii  libx11-6   2:1.3.2-1 X11 client-side library
ii  libxext6   2:1.0.4-1 X11 miscellaneous extension librar
ii  libxmu62:1.0.5-1 X11 miscellaneous utility library
ii  libxrender11:0.9.5-1 X Rendering Extension client libra
ii  libxt6 1:1.0.7-1 X11 toolkit intrinsics library
ii  lxterminal [x-terminal 0.1.6-1+b1desktop independent vte-based term
ii  mrxvt [x-terminal-emul 0.5.4-1   lightweight multi-tabbed X termina
ii  python2.5  2.5.4-3   An interactive high-level object-o
ii  rxvt [x-terminal-emula 1:2.6.4-14VT102 terminal emulator for the X 
ii  tcl8.4 8.4.19-4  Tcl (the Tool Command Language) v8
ii  tk8.4  8.4.19-4  Tk toolkit for Tcl and X11, v8.4 -
ii  unixodbc   2.2.11-21 ODBC tools libraries
ii  wterm [x-terminal-emul 6.2.9-8   lightweight terminal emulator for 
ii  xfce4-terminal [x-term 0.4.3-1   Xfce terminal emulator
ii  xterm [x-terminal-emul 251-1 X terminal emulator
ii  xvt [x-terminal-emulat 2.1-20X terminal-emulator similar to xte
ii  zlib1g 1:1.2.3.3.dfsg-15 compression library - runtime

Versions of packages grass recommends:
ii  ghostscript   8.70~dfsg-2+b1 The GPL Ghostscript PostScript/PDF
ii  python2.5.4-4An interactive high-level object-o
ii  python-numpy  1:1.3.0-3  Numerical Python adds a fast array

Versions of packages grass suggests:
ii  avce00 2.0.0-2   Tools for conversion of ESRI Arcin
ii  curl   7.19.7-1  Get a file from an HTTP, HTTPS or 
ii  e00compr   1.0.1-1   a program to read/write Arc/Info c
ii  gdal-bin   1.6.3-1   Geospatial Data Abstraction Librar
ii  gnuplot4.2.6-1   A command-line driven interactive 
ii  gpsbabel   1.3.6-3   GPS file conversion plus transfer 
ii  gpstrans   0.41-2communicate with a Garmin Global P
ii  grass-doc [grass-doc]  6.4.0~rc5+40109-1 Geographic Resources Analysis Supp
ii  proj-bin   4.7.0-1   Cartographic projection library (t
ii  python-opengl  3.0.0~c1-1Python bindings to OpenGL
ii  python-wxgtk2.82.8.10.1-2wxWidgets Cross-platform C++ GUI t
ii  wget   1.12-1.1  retrieves files from the web
pn